@@ -14,7 +14,7 @@ import typer
 import yaml
 
 from hud.clients import MCPClient
-from hud.utils.design import HUDDesign
+from hud.utils.hud_console import HUDConsole
 from hud.version import __version__ as hud_version
 
 from .utils.registry import save_to_registry
@@ -156,7 +156,7 @@ async def analyze_mcp_environment(
     image: str, verbose: bool = False, env_vars: dict[str, str] | None = None
 ) -> dict[str, Any]:
     """Analyze an MCP environment to extract metadata."""
-    design = HUDDesign()
+    hud_console = HUDConsole()
     env_vars = env_vars or {}
 
     # Build Docker command to run the image
@@ -180,7 +180,7 @@ async def analyze_mcp_environment(
 
     try:
         if verbose:
-            design.info(f"Initializing MCP client with command: {' '.join(docker_cmd)}")
+            hud_console.info(f"Initializing MCP client with command: {' '.join(docker_cmd)}")
 
         await client.initialize()
         initialized = True
@@ -215,7 +215,7 @@ async def analyze_mcp_environment(
                 await client.shutdown()
             except Exception:
                 # Ignore shutdown errors
-                design.warning("Failed to shutdown MCP client")
+                hud_console.warning("Failed to shutdown MCP client")
 
 
 def build_docker_image(
@@ -224,19 +224,23 @@ def build_docker_image(
     no_cache: bool = False,
     verbose: bool = False,
     build_args: dict[str, str] | None = None,
+    platform: str | None = None,
 ) -> bool:
     """Build a Docker image from a directory."""
-    design = HUDDesign()
+    hud_console = HUDConsole()
     build_args = build_args or {}
 
     # Check if Dockerfile exists
     dockerfile = directory / "Dockerfile"
     if not dockerfile.exists():
-        design.error(f"No Dockerfile found in {directory}")
+        hud_console.error(f"No Dockerfile found in {directory}")
         return False
 
     # Build command
-    cmd = ["docker", "build", "-t", tag]
+    cmd = ["docker", "build"]
+    if platform:
+        cmd.extend(["--platform", platform])
+    cmd.extend(["-t", tag])
     if no_cache:
         cmd.append("--no-cache")
 
@@ -247,14 +251,14 @@ def build_docker_image(
     cmd.append(str(directory))
 
     # Always show build output
-    design.info(f"Running: {' '.join(cmd)}")
+    hud_console.info(f"Running: {' '.join(cmd)}")
 
     try:
         # Use Docker's native output formatting - no capture, let Docker handle display
         result = subprocess.run(cmd, check=False)  # noqa: S603
         return result.returncode == 0
     except Exception as e:
-        design.error(f"Build error: {e}")
+        hud_console.error(f"Build error: {e}")
         return False
 
 
@@ -264,22 +268,23 @@ def build_environment(
     no_cache: bool = False,
     verbose: bool = False,
     env_vars: dict[str, str] | None = None,
+    platform: str | None = None,
 ) -> None:
     """Build a HUD environment and generate lock file."""
-    design = HUDDesign()
+    hud_console = HUDConsole()
     env_vars = env_vars or {}
-    design.header("HUD Environment Build")
+    hud_console.header("HUD Environment Build")
 
     # Resolve directory
     env_dir = Path(directory).resolve()
     if not env_dir.exists():
-        design.error(f"Directory not found: {directory}")
+        hud_console.error(f"Directory not found: {directory}")
         raise typer.Exit(1)
 
     # Check for pyproject.toml
     pyproject_path = env_dir / "pyproject.toml"
     if not pyproject_path.exists():
-        design.error(f"No pyproject.toml found in {directory}")
+        hud_console.error(f"No pyproject.toml found in {directory}")
         raise typer.Exit(1)
 
     # Read pyproject.toml to get image name
@@ -294,24 +299,30 @@ def build_environment(
     except Exception:
         default_image = f"{env_dir.name}:dev"
 
-    # Use provided tag or default
-    if not tag:
-        tag = default_image
+    # Determine final image tag to use
+    image_tag: str = tag if tag else default_image
 
     # Build temporary image first
     temp_tag = f"hud-build-temp:{int(time.time())}"
 
-    design.progress_message(f"Building Docker image: {temp_tag}")
+    hud_console.progress_message(f"Building Docker image: {temp_tag}")
 
     # Build the image (env vars are for runtime, not build time)
-    if not build_docker_image(env_dir, temp_tag, no_cache, verbose):
-        design.error("Docker build failed")
+    if not build_docker_image(
+        env_dir,
+        temp_tag,
+        no_cache,
+        verbose,
+        build_args=None,
+        platform=platform,
+    ):
+        hud_console.error("Docker build failed")
         raise typer.Exit(1)
 
-    design.success(f"Built temporary image: {temp_tag}")
+    hud_console.success(f"Built temporary image: {temp_tag}")
 
     # Analyze the environment
-    design.progress_message("Analyzing MCP environment...")
+    hud_console.progress_message("Analyzing MCP environment...")
 
     loop = asyncio.new_event_loop()
     asyncio.set_event_loop(loop)
@@ -320,7 +331,7 @@ def build_environment(
     finally:
         loop.close()
 
-    design.success(f"Analyzed environment: {analysis['toolCount']} tools found")
+    hud_console.success(f"Analyzed environment: {analysis['toolCount']} tools found")
 
     # Extract environment variables from Dockerfile
     dockerfile_path = env_dir / "Dockerfile"
@@ -335,14 +346,18 @@ def build_environment(
         missing_required = [e for e in required_env if e not in env_vars]
 
         # Show what env vars were provided
-        design.success(f"Using provided environment variables: {', '.join(env_vars.keys())}")
+        hud_console.success(f"Using provided environment variables: {', '.join(env_vars.keys())}")
     else:
         missing_required = required_env[:]
 
     # Warn about missing required variables
     if missing_required:
-        design.warning(f"Missing required environment variables: {', '.join(missing_required)}")
-        design.info("These can be added to the lock file after build or provided with -e flags")
+        hud_console.warning(
+            f"Missing required environment variables: {', '.join(missing_required)}"
+        )
+        hud_console.info(
+            "These can be added to the lock file after build or provided with -e flags"
+        )
 
     # Check for existing version and increment
     lock_path = env_dir / "hud.lock.yaml"
@@ -351,11 +366,11 @@ def build_environment(
     if existing_version:
         # Increment existing version
         new_version = increment_version(existing_version)
-        design.info(f"Incrementing version: {existing_version} → {new_version}")
+        hud_console.info(f"Incrementing version: {existing_version} → {new_version}")
     else:
         # Start with 0.1.0 for new environments
         new_version = "0.1.0"
-        design.info(f"Setting initial version: {new_version}")
+        hud_console.info(f"Setting initial version: {new_version}")
 
     # Create lock file content - minimal and useful
     lock_content = {
@@ -406,7 +421,7 @@ def build_environment(
     with open(lock_path, "w") as f:
         yaml.dump(lock_content, f, default_flow_style=False, sort_keys=False)
 
-    design.success("Created lock file: hud.lock.yaml")
+    hud_console.success("Created lock file: hud.lock.yaml")
 
     # Calculate lock file hash
     lock_content_str = yaml.dump(lock_content, default_flow_style=False, sort_keys=True)
@@ -414,25 +429,28 @@ def build_environment(
     lock_size = len(lock_content_str)
 
     # Rebuild with label containing lock file hash
-    design.progress_message("Rebuilding with lock file metadata...")
+    hud_console.progress_message("Rebuilding with lock file metadata...")
 
     # Build final image with label (uses cache from first build)
     # Also tag with version
-    base_name = tag.split(":")[0] if tag and ":" in tag else tag
+    base_name = image_tag.split(":")[0] if ":" in image_tag else image_tag
     version_tag = f"{base_name}:{new_version}"
 
-    label_cmd = [
-        "docker",
-        "build",
-        "--label",
-        f"org.hud.manifest.head={lock_hash}:{lock_size}",
-        "--label",
-        f"org.hud.version={new_version}",
-        "-t",
-        tag,
-        "-t",
-        version_tag,
-    ]
+    label_cmd = ["docker", "build"]
+    if platform is not None:
+        label_cmd.extend(["--platform", platform])
+    label_cmd.extend(
+        [
+            "--label",
+            f"org.hud.manifest.head={lock_hash}:{lock_size}",
+            "--label",
+            f"org.hud.version={new_version}",
+            "-t",
+            image_tag,
+            "-t",
+            version_tag,
+        ]
+    )
 
     label_cmd.append(str(env_dir))
 
@@ -447,28 +465,28 @@ def build_environment(
         )
 
     if result.returncode != 0:
-        design.error("Failed to rebuild with label")
+        hud_console.error("Failed to rebuild with label")
         raise typer.Exit(1)
 
-    design.success("Built final image with lock file metadata")
+    hud_console.success("Built final image with lock file metadata")
 
     # NOW get the image ID after the final build
-    image_id = get_docker_image_id(tag)  # type: ignore
+    image_id = get_docker_image_id(image_tag)
     if image_id:
         # For local builds, store the image ID
         # Docker IDs come as sha256:hash, we want tag@sha256:hash
         if image_id.startswith("sha256:"):
-            lock_content["image"] = f"{tag}@{image_id}"
+            lock_content["image"] = f"{image_tag}@{image_id}"
         else:
-            lock_content["image"] = f"{tag}@sha256:{image_id}"
+            lock_content["image"] = f"{image_tag}@sha256:{image_id}"
 
         # Update the lock file with the new image reference
         with open(lock_path, "w") as f:
             yaml.dump(lock_content, f, default_flow_style=False, sort_keys=False)
 
-        design.success("Updated lock file with image ID")
+        hud_console.success("Updated lock file with image ID")
     else:
-        design.warning("Could not retrieve image ID for lock file")
+        hud_console.warning("Could not retrieve image ID for lock file")
 
     # Remove temp image after we're done
     subprocess.run(["docker", "rmi", temp_tag], capture_output=True)  # noqa: S603, S607
@@ -479,30 +497,30 @@ def build_environment(
         save_to_registry(lock_content, lock_content.get("image", tag), verbose)
 
     # Print summary
-    design.section_title("Build Complete")
+    hud_console.section_title("Build Complete")
 
     # Show the version tag as primary since that's what will be pushed
-    design.status_item("Built image", version_tag, primary=True)
-    if tag:
-        design.status_item("Also tagged", tag)
-    design.status_item("Version", new_version)
-    design.status_item("Lock file", "hud.lock.yaml")
-    design.status_item("Tools found", str(analysis["toolCount"]))
+    hud_console.status_item("Built image", version_tag, primary=True)
+    if image_tag:
+        hud_console.status_item("Also tagged", image_tag)
+    hud_console.status_item("Version", new_version)
+    hud_console.status_item("Lock file", "hud.lock.yaml")
+    hud_console.status_item("Tools found", str(analysis["toolCount"]))
 
     # Show the digest info separately if we have it
     if image_id:
-        design.dim_info("\nImage digest", image_id)
+        hud_console.dim_info("\nImage digest", image_id)
 
-    design.section_title("Next Steps")
-    design.info("Test locally:")
-    design.command_example("hud dev", "Hot-reload development")
-    design.command_example(f"hud run {tag}", "Run the built image")
-    design.info("")
-    design.info("Publish to registry:")
-    design.command_example("hud push", f"Push as {version_tag}")
-    design.command_example("hud push --tag latest", "Push with custom tag")
-    design.info("")
-    design.info("The lock file can be used to reproduce this exact environment.")
+    hud_console.section_title("Next Steps")
+    hud_console.info("Test locally:")
+    hud_console.command_example("hud dev", "Hot-reload development")
+    hud_console.command_example(f"hud run {image_tag}", "Run the built image")
+    hud_console.info("")
+    hud_console.info("Publish to registry:")
+    hud_console.command_example("hud push", f"Push as {version_tag}")
+    hud_console.command_example("hud push --tag latest", "Push with custom tag")
+    hud_console.info("")
+    hud_console.info("The lock file can be used to reproduce this exact environment.")
 
 
 def build_command(
@@ -513,6 +531,7 @@ def build_command(
     no_cache: bool = typer.Option(False, "--no-cache", help="Build without Docker cache"),
     verbose: bool = typer.Option(False, "--verbose", "-v", help="Show detailed output"),
     env_vars: dict[str, str] | None = None,
+    platform: str | None = None,
 ) -> None:
     """Build a HUD environment and generate lock file."""
-    build_environment(directory, tag, no_cache, verbose, env_vars)
+    build_environment(directory, tag, no_cache, verbose, env_vars, platform)
